{% extends "helpdesk/base.html" %}{% load i18n %}{% load url from future %}

{% block helpdesk_title %}{% trans "Delete Ticket Dependency" %}{% endblock %}

{% block helpdesk_body %}{% blocktrans %}
<h2>Delete Ticket Dependency</h2>

<p>Are you sure you wish to remove the dependency on this ticket?</p>
{% endblocktrans %}

<p><a href='../../'>{% trans "Don't Delete" %}</a></p>

<form method='post' action='./'><input type='submit' value='{% trans "Yes, Delete" %}' />{% csrf_token %}</form>
{% endblock %}
